window.Gleam.initSearch([{"doc":"halo","title":"halo","content":"# halo\r\n\r\nA hot-reloading repl for Gleam.\r\n\r\n# Installation\r\n\r\n## Releases\r\nDownload a release off of the releases tab on this github, add it to your path somewhere, and invoke it as `halo`.\r\n\r\n## Gleam\r\nrun `gleam add halo` and invoke it as `gleam run -m halo`. Must be installed once per project.\r\n\r\n## Build from source\r\nClone the repository, build it, and then use `mote` to package it or otherwise figure out how to invoke it.\r\n\r\n# Usage\r\n\r\nInvoke the REPL via `halo` in the console, and use it as a normal erl shell. It will automatically search the directory it&#39;s invoked in (recursively) for altered gleam files, invoke the gleam compiler (`gleam build`) in its directory, and then reload any modules it sees are changed. If you attempt to reload twice while code is still running from before a reload, you will have to kill that code somehow before it will reload again. If you use fully qualified calls in a loop, (`module:func` instead of `func`) it will jump to the newest loaded version of the function rather than continuing to stay old.\r\n\r\n# Disclaimer\r\n\r\nIt is likely that changing types or the signatures of functions will lead to issues during hot reloading. It won&#39;t crash the shell (probably) but your code might all break. This is because gleam&#39;s static type system exists only at compile time, and becomes erlang&#39;s dynamic type system afterwards. To prevent this, make sure to specify function signatures, avoid changing them, and avoid changing type definitions while hot reloading. That said, it&#39;s entirely possible to make such changes in a way that does not break, so don&#39;t be afraid to. The worst that will happen is some code running in the shell fails.\r\n\r\n# Demo\r\n\r\nhttps://github.com/PROMETHIA-27/halo/assets/42193387/8a831640-f12d-4fa9-b976-85e21e55e650\r\n","url":"index.html"},{"doc":"halo/modres","title":"Module","content":"pub external type Module\n\n\nSynonyms:\nhalo/modres.Module\nhalo/modres Module","url":"halo/modres.html#Module"},{"doc":"halo/modres","title":"ModuleResult","content":"pub type ModuleResult {\n  Ok\n  Error(List(#(Module, What)))\n}\n\nOk\n\n\nError(List(#(Module, What)))\n\n\nSynonyms:\nhalo/modres.ModuleResult\nhalo/modres ModuleResult","url":"halo/modres.html#ModuleResult"},{"doc":"halo/modres","title":"What","content":"pub type What {\n  Badfile\n  Nofile\n  OnLoadNotAllowed\n  Duplicated\n  NotPurged\n  StickyDirectory\n  PendingOnLoad\n}\n\nBadfile\n\n\nNofile\n\n\nOnLoadNotAllowed\n\n\nDuplicated\n\n\nNotPurged\n\n\nStickyDirectory\n\n\nPendingOnLoad\n\n\nSynonyms:\nhalo/modres.What\nhalo/modres What","url":"halo/modres.html#What"},{"doc":"halo/modres","title":"halo/modres","content":" Had to move this type to a new module so it didn&#39;t collide with `Result`","url":"halo/modres.html"},{"doc":"halo/shell","title":"AlreadyStarted","content":"pub type AlreadyStarted {\n  AlreadyStarted\n}\n\nAlreadyStarted\n\n\nSynonyms:\nhalo/shell.AlreadyStarted\nhalo/shell AlreadyStarted","url":"halo/shell.html#AlreadyStarted"},{"doc":"halo/shell","title":"ShellResult","content":"pub type ShellResult {\n  Ok\n  Error(AlreadyStarted)\n}\n\nOk\n\n\nError(AlreadyStarted)\n\n\nSynonyms:\nhalo/shell.ShellResult\nhalo/shell ShellResult","url":"halo/shell.html#ShellResult"},{"doc":"halo/shell","title":"start","content":"pub external fn start() -&gt; ShellResult\n\nSynonyms:\nhalo/shell.start\nhalo/shell start","url":"halo/shell.html#start"},{"doc":"halo/shell","title":"halo/shell","content":"","url":"halo/shell.html"},{"doc":"halo/code","title":"add_paths","content":"pub fn add_paths(paths: List(String)) -&gt; ModuleResult\n\nSynonyms:\nhalo/code.add_paths\nhalo/code add_paths","url":"halo/code.html#add_paths"},{"doc":"halo/code","title":"add_paths_internal","content":"pub external fn add_paths_internal(\n  paths: List(charlist.Charlist),\n) -&gt; modres.ModuleResult\n\nSynonyms:\nhalo/code.add_paths_internal\nhalo/code add_paths_internal","url":"halo/code.html#add_paths_internal"},{"doc":"halo/code","title":"atomic_load","content":"pub external fn atomic_load(List(Module)) -&gt; modres.ModuleResult\n\nSynonyms:\nhalo/code.atomic_load\nhalo/code atomic_load","url":"halo/code.html#atomic_load"},{"doc":"halo/code","title":"modified_modules","content":"pub external fn modified_modules() -&gt; List(Module)\n\nSynonyms:\nhalo/code.modified_modules\nhalo/code modified_modules","url":"halo/code.html#modified_modules"},{"doc":"halo/code","title":"module_name","content":"pub external fn module_name(Module) -&gt; String\n\nSynonyms:\nhalo/code.module_name\nhalo/code module_name","url":"halo/code.html#module_name"},{"doc":"halo/code","title":"soft_purge","content":"pub external fn soft_purge(Module) -&gt; Bool\n\nSynonyms:\nhalo/code.soft_purge\nhalo/code soft_purge","url":"halo/code.html#soft_purge"},{"doc":"halo/code","title":"soft_purge_all","content":"pub fn soft_purge_all(modules: List(Module)) -&gt; Result(\n  Nil,\n  Module,\n)\n\nSynonyms:\nhalo/code.soft_purge_all\nhalo/code soft_purge_all","url":"halo/code.html#soft_purge_all"},{"doc":"halo/code","title":"halo/code","content":"","url":"halo/code.html"},{"doc":"halo/fs","title":"LinkError","content":"pub external type LinkError\n\n\nSynonyms:\nhalo/fs.LinkError\nhalo/fs LinkError","url":"halo/fs.html#LinkError"},{"doc":"halo/fs","title":"SubscribeResult","content":"pub external type SubscribeResult\n\n\nSynonyms:\nhalo/fs.SubscribeResult\nhalo/fs SubscribeResult","url":"halo/fs.html#SubscribeResult"},{"doc":"halo/fs","title":"start_link","content":"pub external fn start_link(\n  watcher: atom.Atom,\n) -&gt; Result(process.Pid, LinkError)\n\nSynonyms:\nhalo/fs.start_link\nhalo/fs start_link","url":"halo/fs.html#start_link"},{"doc":"halo/fs","title":"subscribe","content":"pub external fn subscribe(watcher: atom.Atom) -&gt; SubscribeResult\n\nSynonyms:\nhalo/fs.subscribe\nhalo/fs subscribe","url":"halo/fs.html#subscribe"},{"doc":"halo/fs","title":"halo/fs","content":"","url":"halo/fs.html"},{"doc":"halo","title":"main","content":"pub fn main() -&gt; a\n\nSynonyms:\nhalo.main\nhalo main","url":"halo.html#main"},{"doc":"halo","title":"update_path","content":"pub fn update_path() -&gt; Nil\n\nSynonyms:\nhalo.update_path\nhalo update_path","url":"halo.html#update_path"},{"doc":"halo","title":"halo","content":"","url":"halo.html"}]);